package io.useless.client

import play.api.libs.ws.WS
import play.api.libs.ws.WS.WSRequestHolder

import io.useless.util.{ Configuration, ConfigurationComponent }

trait BaseClient
  extends ConfigurableBaseClientComponent
  with    Configuration
{

  def baseClient = new ConfigurableBaseClient

}

trait BaseClientComponent {

  def baseClient: BaseClient

  trait BaseClient {

    def request(path: String): WSRequestHolder

  }

}

trait ConfigurableBaseClientComponent extends BaseClientComponent {

  self: ConfigurationComponent =>

  class ConfigurableBaseClient extends BaseClient {

    private lazy val baseUrl = configuration.underlying.getString("useless.baseUrl")

    private lazy val clientGuid = configuration.underlying.getString("useless.client.guid")

    def request(path: String) = WS.url(baseUrl + path).withHeaders(("Authorization", clientGuid))

  }

}
