package io.useless.play.authentication

import java.util.UUID
import scala.concurrent.{ Future, future }
import scala.concurrent.ExecutionContext.Implicits.global

import io.useless.auth.AccessToken
import io.useless.client.AuthClient

trait AuthDaoComponent {

  def authDao: AuthDao

  trait AuthDao {

    def getAccessToken(guid: UUID): Future[Option[AccessToken]]

  }

}

trait MockAuthDaoComponent extends AuthDaoComponent {

  class MockAuthDao(accessTokens: Seq[AccessToken]) extends AuthDao {

    def getAccessToken(guid: UUID) = {
      future { accessTokens.find { _.guid == guid } }
    }

  }

}

trait ClientAuthDaoComponent extends AuthDaoComponent {

  class ClientAuthDao extends AuthDao {

    private lazy val authClient = new AuthClient

    def getAccessToken(guid: UUID) = authClient.getAccessToken(guid)

  }

}
