package io.useless.play.authentication

import scala.concurrent.{ Future, future }
import scala.concurrent.ExecutionContext.Implicits.global

import io.useless.auth.Account
import io.useless.auth.Role._

trait AuthorizerComponent {

  val authorizer: Authorizer

  trait Authorizer {

    def authorize(account: Account): Future[Boolean]

  }

}

trait OpenAuthorizerComponent extends AuthorizerComponent {

  class OpenAuthorizer extends Authorizer {

    def authorize(account: Account) = future { true }

  }

}

trait RoleAuthorizerComponent extends AuthorizerComponent {

  class RoleAuthorizer(requiredRoles: Seq[Role]) extends Authorizer {

    def authorize(account: Account) = {
      future { requiredRoles.forall { account.roles.contains(_) } }
    }

  }

}
